#!/bin/sh
export PATH='/usr/obj/ports/hs-HDBC-2.4.0.0/bin:/usr/bin:/bin:/usr/sbin:/sbin:/usr/local/bin:/usr/local/bin:/usr/X11R6/bin'
echo 'name: HDBC
version: 2.4.0.0
id: HDBC-2.4.0.0-3ae4d4df9f3738c553c3bbc8068067d1

license: BSD3
copyright: Copyright (c) 2005-2011 John Goerzen
maintainer: Nicolas Wu <nicolas.wu@gmail.com>
stability: Stable
homepage: https://github.com/hdbc/hdbc
package-url:
synopsis: Haskell Database Connectivity
description: HDBC provides an abstraction layer between Haskell programs and SQL
             relational databases. This lets you write database code once, in
             Haskell, and have it work with any number of backend SQL databases
             (MySQL, Oracle, PostgreSQL, ODBC-compliant databases, etc.)
category: Database
author: John Goerzen, Nicolas Wu
pkgpath: databases/hs-HDBC
exposed: True
exposed-modules: Database.HDBC Database.HDBC.Types
                 Database.HDBC.DriverUtils Database.HDBC.ColTypes
                 Database.HDBC.Statement Database.HDBC.SqlValue Database.HDBC.Locale
hidden-modules: Database.HDBC.Utils
trusted: False
import-dirs: /usr/local/lib/ghc/HDBC-2.4.0.0
library-dirs: /usr/local/lib/ghc/HDBC-2.4.0.0
hs-libraries: HSHDBC-2.4.0.0
extra-libraries:
extra-ghci-libraries:
include-dirs:
includes:
depends: base-4.7.0.2-b11c3b9ddc2bebe1a3d85499c9ea3f18
         bytestring-0.10.4.0-c38ffa96fe2b16989b0dffe49eb81a0b
         containers-0.5.5.1-171870bb1335468dfd35b06f64ad39aa
         convertible-1.1.0.0-28989c2b8ff74cb2fd86deba0c48707c
         mtl-2.1.3.1-37f47084eacfb82b92e11a8c90d0ba72
         old-locale-1.0.0.6-5787526c2e79da8a846be3a88dc42a6d
         old-time-1.1.0.2-4d6b62bf66ac20e6550b5bf9e9cfea48
         text-1.1.0.0-6c72ebcdf327be13b3762cdaa7b368bd
         time-1.4.2-fc089836b34bdfee5ff8fc5b4f21945e
         utf8-string-0.3.8-deb6f3b52f6d22ffddb7305b5e4f676f
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/hs-HDBC-2.4.0.0/html/HDBC.haddock
haddock-html: /usr/local/share/doc/hs-HDBC-2.4.0.0/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
